@@ -2,5 +2,5 @@
 
 class DefaultDjangoUser(object):
 
-    def get_user(self, consumer):
+    async def get_user(self, consumer):
         return consumer.scope['user']
