@@ -12,7 +12,7 @@ DEFAULT_CHANNELS_BINDING = {
     ),
     "DEFAULT_PAGE_SIZE": 25,
     "AUTO_CONNECT_MODEL_SIGNALS": True,
-    "ANONYMOUS_CONNECTION_ALLOWED": False,
+    "ANONYMOUS_CONNECTION_ALLOWED": True,
 }
 
 
